@@ -131,6 +131,10 @@ class accuinsight(Common):
             # sklearn/xgboost/lightgbm
             get_from_model = get.from_model(self.model_name)
             self.all_model_params = get_from_model.all_params()
+
+            if 'metric' not in self.all_model_params.keys():
+                self.all_model_params['metric'] = ''
+
             self.model_param_keys = get_from_model.param_keys()
             
             # classifier
