@@ -37,13 +37,13 @@ class accuinsight(Common):
         super().get_file(storage_json_file_name)
 
     def autolog(self, tag=None, best_weights=False, model_monitor=False):
-        global description, endpoint, var_model_file_path, message, thresholds, token, channel_id, best_weights_on, run_id, shap_on, feature_name
+        global description, endpoint, var_model_file_path, message, thresholds, best_weights_on, run_id, alarm, alarm_api, shap_on, feature_name
         description = tag
         endpoint = self.endpoint
         message = self.message
         thresholds = self.thresholds
-        token = self.token
-        channel_id = self.channel_id
+        alarm = self.workspace_alarm
+        alarm_api = self.workspace_alarm_api
     
         if best_weights:
             best_weights_on = True
@@ -69,8 +69,7 @@ class accuinsight(Common):
             shap_on = False
         run_id = None
 
-        is_notebook = is_in_ipython()
-        if is_notebook:
+        if is_in_ipython():
             var_model_file_path = get_current_notebook()
             _caller_globals = inspect.stack()[1][0].f_globals
             (
@@ -250,9 +249,8 @@ class accuinsight(Common):
                 accuinsight._send_message(metric=self.monitor,
                                           current_value=self.current_value,
                                           message=message,
-                                          thresholds=thresholds,
-                                          token=token,
-                                          channel_id=channel_id)
+                                          alarm_object=alarm,
+                                          alarm_api=alarm_api)
                 env_value = get_os_env('ENV')
                 modeler_rest = LifecycleRestApi(env_value[LcConst.BACK_END_API_URL],
                                                 env_value[LcConst.BACK_END_API_PORT],
@@ -381,7 +379,7 @@ class accuinsight(Common):
     def _off_autolog():
         def stop_log(self, original, args, kwargs, unlogged_params):
             fit_model = original(self, *args, **kwargs)
-            return (fit_model)
+            return fit_model
 
         @gorilla.patch(tensorflow.keras.Model)
         def fit(self, *args, **kwargs):
