@@ -40,8 +40,9 @@ class WorkspaceRun:
         try:
             subprocess.run("python3 -u %s > "
                            "/tmp/output_%s.log 2>&1"
-                           % (self.code_path, self.workspace_run_log.workspace_run_id), shell=True, encoding='UTF-8')\
-                .check_returncode()
+                           % (self.code_path + ' ' + ' '.join(unknown),
+                              self.workspace_run_log.workspace_run_id),
+                           shell=True, encoding='UTF-8').check_returncode()
             self.workspace_run_log.is_success = True
         except subprocess.CalledProcessError:
             self.workspace_run_log.is_success = False
