@@ -68,13 +68,13 @@ ENV_LANGUAGE_ID = 'LC_LANGUAGE_ID'
 ENV_JUPYTER_WORKSPACE = '/home/notebook/.jupyter/lab/workspaces'
 ENV_JUPYTER_HOME_DIR = '/home/work'
 
-DB_CONNECT_USER = 'modeler'
-DB_CONNECT_PASSWD = '!Modeleradmin1234'
-DB_CONNECT_HOST = 'accuinsight.mariadb.database.azure.com'
-DB_CONNECT_PORT = 3306
-DB_CONNECT_DB = 'modeler'
+DB_CONNECT_USER = 'ENV_DB_CONNECT_USER'
+DB_CONNECT_PASSWD = 'ENV_DB_CONNECT_PASSWD'
+DB_CONNECT_HOST = 'ENV_DB_CONNECT_HOST'
+DB_CONNECT_PORT = 'ENV_DB_CONNECT_PORT'
+DB_CONNECT_DB = 'ENV_DB_CONNECT_DB'
 DB_CONNECT_CHARSET = 'utf8'
 
-BACK_END_API_URI = ''
-BACK_END_API_URL = 'modeler-api.accu'
-BACK_END_API_PORT = '8080'
+BACK_END_API_URI = 'ENV_BACK_END_API_URI'
+BACK_END_API_URL = 'ENV_BACK_END_API_URL'
+BACK_END_API_PORT = 'ENV_BACK_END_API_PORT'
