@@ -66,11 +66,11 @@ def get_current_notebook():
     if is_in_ipython():
         target_path = LcConst.ENV_JUPYTER_WORKSPACE
         # '/home/notebook/.jupyter/lab/workspaces'
-        if os.path.isdir(target_path):
+        if os.path.isdir(target_path): # if jupyter lab
             return __get_current_file(target_path=target_path,
                                       target_file=__list_jupyterlab_workspace(targtet_path=target_path)[0]
                                       ).split(':')[1]
         else:
             __install_package('ipyparams')
             import ipyparams
-            return ipyparams.raw_url.split('notebooks/')[1]
+            return ipyparams.notebook_name
